@@ -1,10 +1,10 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, DUMMY_NODE};
+use super::{Context, LintRule};
 use crate::ProgramRef;
 use deno_ast::swc::ast::{BinExpr, BinaryOp, Expr, IfStmt, ParenExpr, Stmt};
 use deno_ast::swc::common::{Span, Spanned};
 use deno_ast::swc::utils::drop_span;
-use deno_ast::swc::visit::{noop_visit_type, Node, VisitAll, VisitAllWith};
+use deno_ast::swc::visit::{noop_visit_type, VisitAll, VisitAllWith};
 use derive_more::Display;
 use std::collections::HashSet;
 use std::sync::Arc;
@@ -50,8 +50,8 @@ impl LintRule for NoDupeElseIf {
   ) {
     let mut visitor = NoDupeElseIfVisitor::new(context);
     match program {
-      ProgramRef::Module(m) => m.visit_all_with(&DUMMY_NODE, &mut visitor),
-      ProgramRef::Script(s) => s.visit_all_with(&DUMMY_NODE, &mut visitor),
+      ProgramRef::Module(m) => m.visit_all_with(&mut visitor),
+      ProgramRef::Script(s) => s.visit_all_with(&mut visitor),
     }
   }
 
@@ -81,7 +81,7 @@ impl<'c, 'view> NoDupeElseIfVisitor<'c, 'view> {
 impl<'c, 'view> VisitAll for NoDupeElseIfVisitor<'c, 'view> {
   noop_visit_type!();
 
-  fn visit_if_stmt(&mut self, if_stmt: &IfStmt, _: &dyn Node) {
+  fn visit_if_stmt(&mut self, if_stmt: &IfStmt) {
     let span = if_stmt.test.span();
 
     // This check is necessary to avoid outputting the same errors multiple times.
